@@ -23,6 +23,7 @@ from snaptrade_client.model.account_simple import AccountSimple
 from snaptrade_client.model.account_sync_status import AccountSyncStatus
 from snaptrade_client.model.action import Action
 from snaptrade_client.model.amount import Amount
+from snaptrade_client.model.amount_nullable import AmountNullable
 from snaptrade_client.model.balance import Balance
 from snaptrade_client.model.brokerage import Brokerage
 from snaptrade_client.model.brokerage_auth_ids import BrokerageAuthIDs
@@ -41,6 +42,7 @@ from snaptrade_client.model.cash_restriction import CashRestriction
 from snaptrade_client.model.client_id import ClientID
 from snaptrade_client.model.consumer_key import ConsumerKey
 from snaptrade_client.model.currency import Currency
+from snaptrade_client.model.currency_nullable import CurrencyNullable
 from snaptrade_client.model.delete_user_response import DeleteUserResponse
 from snaptrade_client.model.dividend_at_date import DividendAtDate
 from snaptrade_client.model.email import Email
@@ -49,6 +51,8 @@ from snaptrade_client.model.encrypted_response_encrypted_message_data import Enc
 from snaptrade_client.model.exchange import Exchange
 from snaptrade_client.model.exchange_rate_pairs import ExchangeRatePairs
 from snaptrade_client.model.excluded_asset import ExcludedAsset
+from snaptrade_client.model.figi_instrument import FigiInstrument
+from snaptrade_client.model.figi_instrument_nullable import FigiInstrumentNullable
 from snaptrade_client.model.filled_units import FilledUnits
 from snaptrade_client.model.id import Id
 from snaptrade_client.model.jwt import JWT
@@ -74,6 +78,7 @@ from snaptrade_client.model.monthly_dividends import MonthlyDividends
 from snaptrade_client.model.net_contributions import NetContributions
 from snaptrade_client.model.net_dividend import NetDividend
 from snaptrade_client.model.notional_value import NotionalValue
+from snaptrade_client.model.notional_value_nullable import NotionalValueNullable
 from snaptrade_client.model.open_units import OpenUnits
 from snaptrade_client.model.option_chain import OptionChain
 from snaptrade_client.model.option_chain_item import OptionChainItem
@@ -87,6 +92,7 @@ from snaptrade_client.model.option_strategy_legs import OptionStrategyLegs
 from snaptrade_client.model.options_holdings import OptionsHoldings
 from snaptrade_client.model.options_position import OptionsPosition
 from snaptrade_client.model.options_symbol import OptionsSymbol
+from snaptrade_client.model.options_symbol_nullable import OptionsSymbolNullable
 from snaptrade_client.model.order_type import OrderType
 from snaptrade_client.model.partner_data import PartnerData
 from snaptrade_client.model.past_value import PastValue
@@ -142,6 +148,8 @@ from snaptrade_client.model.target_asset_list import TargetAssetList
 from snaptrade_client.model.target_asset_meta import TargetAssetMeta
 from snaptrade_client.model.time import Time
 from snaptrade_client.model.time_in_force import TimeInForce
+from snaptrade_client.model.time_in_force_strict import TimeInForceStrict
+from snaptrade_client.model.time_nullable import TimeNullable
 from snaptrade_client.model.timestamp import Timestamp
 from snaptrade_client.model.trade import Trade
 from snaptrade_client.model.trade_execution_status import TradeExecutionStatus
@@ -151,12 +159,14 @@ from snaptrade_client.model.transactions_status import TransactionsStatus
 from snaptrade_client.model.us_exchange import USExchange
 from snaptrade_client.model.underlying_symbol import UnderlyingSymbol
 from snaptrade_client.model.units import Units
+from snaptrade_client.model.units_nullable import UnitsNullable
 from snaptrade_client.model.universal_activity import UniversalActivity
 from snaptrade_client.model.universal_symbol import UniversalSymbol
-from snaptrade_client.model.universal_symbol_ticker import UniversalSymbolTicker
+from snaptrade_client.model.universal_symbol_nullable import UniversalSymbolNullable
 from snaptrade_client.model.user_error_log import UserErrorLog
 from snaptrade_client.model.user_id import UserID
 from snaptrade_client.model.user_i_dand_secret import UserIDandSecret
 from snaptrade_client.model.user_list import UserList
 from snaptrade_client.model.user_secret import UserSecret
 from snaptrade_client.model.user_settings import UserSettings
+from snaptrade_client.model.validated_trade_body import ValidatedTradeBody
