@@ -13,6 +13,7 @@
 from dataclasses import dataclass
 import typing_extensions
 import urllib3
+from snaptrade_client.request_before_hook import request_before_hook
 import json
 from urllib3._collections import HTTPHeaderDict
 
@@ -249,10 +250,11 @@ class BaseApi(api_client.Api):
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -286,21 +288,32 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            path_template='/trade/oco',
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_typing_any.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = await self.api_client.async_call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -308,9 +321,18 @@ class BaseApi(api_client.Api):
             auth_settings=_auth,
             prefix_separator_iterator=prefix_separator_iterator,
             timeout=timeout,
+            **kwargs
         )
-        
+    
         if stream:
+            if not 200 <= response.http_response.status <= 299:
+                body = (await response.http_response.content.read()).decode("utf-8")
+                raise exceptions.ApiStreamingException(
+                    status=response.http_response.status,
+                    reason=response.http_response.reason,
+                    body=body,
+                )
+    
             async def stream_iterator():
                 """
                 iterates over response.http_response.content and closes connection once iteration has finished
@@ -355,12 +377,13 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
     def _place_oco_order_oapg(
         self,
         body: typing.Any = None,
         query_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         content_type: str = 'application/json',
         stream: bool = False,
@@ -396,21 +419,32 @@ class BaseApi(api_client.Api):
         if accept_content_types:
             for accept_content_type in accept_content_types:
                 _headers.add('Accept', accept_content_type)
+        method = 'post'.upper()
+        _headers.add('Content-Type', content_type)
     
         if body is schemas.unset:
             raise exceptions.ApiValueError(
                 'The required body parameter has an invalid value of: unset. Set a valid value instead')
         _fields = None
         _body = None
+        request_before_hook(
+            resource_path=used_path,
+            method=method,
+            configuration=self.api_client.configuration,
+            path_template='/trade/oco',
+            body=body,
+            auth_settings=_auth,
+            headers=_headers,
+        )
         serialized_data = request_body_typing_any.serialize(body, content_type)
-        _headers.add('Content-Type', content_type)
         if 'fields' in serialized_data:
             _fields = serialized_data['fields']
         elif 'body' in serialized_data:
-            _body = serialized_data['body']    
+            _body = serialized_data['body']
+    
         response = self.api_client.call_api(
             resource_path=used_path,
-            method='post'.upper(),
+            method=method,
             headers=_headers,
             fields=_fields,
             serialized_body=_body,
@@ -443,9 +477,11 @@ class BaseApi(api_client.Api):
     
         return api_response
 
+
 class PlaceOcoOrder(BaseApi):
     # this class is used by api classes that refer to endpoints with operationId fn names
 
+    @api_client.DeprecationWarningOnce(prefix="trading")
     async def aplace_oco_order(
         self,
         body: typing.Optional[typing.Any] = None,
@@ -454,6 +490,7 @@ class PlaceOcoOrder(BaseApi):
         first_trade_id: typing.Optional[typing.Union[bool, date, datetime, dict, float, int, list, str, None]] = None,
         second_trade_id: typing.Optional[typing.Union[bool, date, datetime, dict, float, int, list, str, None]] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -470,8 +507,10 @@ class PlaceOcoOrder(BaseApi):
         return await self._aplace_oco_order_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
+    @api_client.DeprecationWarningOnce(prefix="trading")
     def place_oco_order(
         self,
         body: typing.Optional[typing.Any] = None,
@@ -500,6 +539,7 @@ class PlaceOcoOrder(BaseApi):
 class ApiForpost(BaseApi):
     # this class is used by api classes that refer to endpoints by path and http method names
 
+    @api_client.DeprecationWarningOnce(prefix="trading")
     async def apost(
         self,
         body: typing.Optional[typing.Any] = None,
@@ -508,6 +548,7 @@ class ApiForpost(BaseApi):
         first_trade_id: typing.Optional[typing.Union[bool, date, datetime, dict, float, int, list, str, None]] = None,
         second_trade_id: typing.Optional[typing.Union[bool, date, datetime, dict, float, int, list, str, None]] = None,
         query_params: typing.Optional[dict] = {},
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -524,8 +565,10 @@ class ApiForpost(BaseApi):
         return await self._aplace_oco_order_oapg(
             body=args.body,
             query_params=args.query,
+            **kwargs,
         )
     
+    @api_client.DeprecationWarningOnce(prefix="trading")
     def post(
         self,
         body: typing.Optional[typing.Any] = None,
