@@ -35,17 +35,21 @@ from snaptrade_client import schemas  # noqa: F401
 from snaptrade_client.model.action import Action as ActionSchema
 from snaptrade_client.model.model400_failed_request_response import Model400FailedRequestResponse as Model400FailedRequestResponseSchema
 from snaptrade_client.model.stop_price import StopPrice as StopPriceSchema
-from snaptrade_client.model.time_in_force import TimeInForce as TimeInForceSchema
+from snaptrade_client.model.units_nullable import UnitsNullable as UnitsNullableSchema
+from snaptrade_client.model.notional_value_nullable import NotionalValueNullable as NotionalValueNullableSchema
 from snaptrade_client.model.account_order_record import AccountOrderRecord as AccountOrderRecordSchema
 from snaptrade_client.model.order_type import OrderType as OrderTypeSchema
 from snaptrade_client.model.manual_trade_form import ManualTradeForm as ManualTradeFormSchema
 from snaptrade_client.model.model403_failed_request_response import Model403FailedRequestResponse as Model403FailedRequestResponseSchema
 from snaptrade_client.model.price import Price as PriceSchema
+from snaptrade_client.model.time_in_force_strict import TimeInForceStrict as TimeInForceStrictSchema
 
 from snaptrade_client.type.action import Action
-from snaptrade_client.type.time_in_force import TimeInForce
+from snaptrade_client.type.notional_value_nullable import NotionalValueNullable
+from snaptrade_client.type.units_nullable import UnitsNullable
 from snaptrade_client.type.manual_trade_form import ManualTradeForm
 from snaptrade_client.type.model400_failed_request_response import Model400FailedRequestResponse
+from snaptrade_client.type.time_in_force_strict import TimeInForceStrict
 from snaptrade_client.type.stop_price import StopPrice
 from snaptrade_client.type.model403_failed_request_response import Model403FailedRequestResponse
 from snaptrade_client.type.account_order_record import AccountOrderRecord
@@ -208,10 +212,10 @@ class BaseApi(api_client.Api):
         order_type: typing.Optional[OrderType] = None,
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[float] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        units: typing.Optional[UnitsNullable] = None,
         universal_symbol_id: typing.Optional[str] = None,
-        notional_value: typing.Optional[float] = None,
+        notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> api_client.MappedArgs:
         args: api_client.MappedArgs = api_client.MappedArgs()
@@ -298,6 +302,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/trade/place',
             body=body,
             auth_settings=_auth,
             headers=_headers,
@@ -428,6 +433,7 @@ class BaseApi(api_client.Api):
             resource_path=used_path,
             method=method,
             configuration=self.api_client.configuration,
+            path_template='/trade/place',
             body=body,
             auth_settings=_auth,
             headers=_headers,
@@ -487,10 +493,10 @@ class PlaceForceOrder(BaseApi):
         order_type: typing.Optional[OrderType] = None,
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[float] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        units: typing.Optional[UnitsNullable] = None,
         universal_symbol_id: typing.Optional[str] = None,
-        notional_value: typing.Optional[float] = None,
+        notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
         **kwargs,
     ) -> typing.Union[
@@ -529,10 +535,10 @@ class PlaceForceOrder(BaseApi):
         order_type: typing.Optional[OrderType] = None,
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[float] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        units: typing.Optional[UnitsNullable] = None,
         universal_symbol_id: typing.Optional[str] = None,
-        notional_value: typing.Optional[float] = None,
+        notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
@@ -571,10 +577,10 @@ class ApiForpost(BaseApi):
         order_type: typing.Optional[OrderType] = None,
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[float] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        units: typing.Optional[UnitsNullable] = None,
         universal_symbol_id: typing.Optional[str] = None,
-        notional_value: typing.Optional[float] = None,
+        notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
         **kwargs,
     ) -> typing.Union[
@@ -613,10 +619,10 @@ class ApiForpost(BaseApi):
         order_type: typing.Optional[OrderType] = None,
         price: typing.Optional[Price] = None,
         stop: typing.Optional[StopPrice] = None,
-        time_in_force: typing.Optional[TimeInForce] = None,
-        units: typing.Optional[float] = None,
+        time_in_force: typing.Optional[TimeInForceStrict] = None,
+        units: typing.Optional[UnitsNullable] = None,
         universal_symbol_id: typing.Optional[str] = None,
-        notional_value: typing.Optional[float] = None,
+        notional_value: typing.Optional[NotionalValueNullable] = None,
         query_params: typing.Optional[dict] = {},
     ) -> typing.Union[
         ApiResponseFor200,
