@@ -17,6 +17,7 @@ from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from snaptrade_client.type.currency import Currency
 from snaptrade_client.type.exchange import Exchange
+from snaptrade_client.type.figi_instrument_nullable import FigiInstrumentNullable
 from snaptrade_client.type.security_type import SecurityType
 
 class RequiredSymbol(TypedDict):
@@ -39,5 +40,7 @@ class OptionalSymbol(TypedDict, total=False):
 
     figi_code: typing.Optional[str]
 
+    figi_instrument: typing.Optional[FigiInstrumentNullable]
+
 class Symbol(RequiredSymbol, OptionalSymbol):
     pass
